@@ -190,6 +190,11 @@ sub _CreateData {
   my $self = shift;
   my $data = $self->baseCreateData(@_);
   $data = $self->CreateData($data) if ($self->can('CreateData'));
+
+  if(my $lock_keys = $self->_get_rs_lock_keys) {
+    $data = { %{ $data || {} }, %$lock_keys }
+  }
+
   return $data;
 }
 
@@ -296,6 +301,49 @@ sub record_pk_cond {
   return \%cond;
 }
 
+# TODO: deprecate/remove in favor of better _ra-rel-mnt_ solution - GitHub Issue #153
+around '_maybe_special_path_redirect' => sub {
+  my ($orig, $self, $opt, @subargs)= @_;
+
+  # This will detach if the special path test matches (original method):
+  $self->$orig($opt, @subargs);
+
+  # Re-test if this is a special path (and redirect) again after stripping
+  # prefixed arguments which correspond to RESTful path patterns, specific to
+  # DbicLnk. This allows relative paths to assets and simplecas, etc, from 
+  # content generated within modules which are loaded in this manner 
+  # (e.g. <module>/item/34/rel/foobar/ and so on)
+  if($self->allow_restful_queries) {
+
+    my $s = sub {
+      my @sargs = @_;
+      # The rel/name form:
+      if($sargs[0] eq 'rel' || $sargs[0] eq 'rs') {
+        shift @sargs;
+        shift @sargs;
+      }
+      $self->$orig(@sargs)
+    };
+
+    # To limit the risk of namespace collisions (since now we're sharing our
+    # namespace with record pk values), require more arguments. This still doesn't
+    # fully eliminate the possibility; if a key/col value matches the pattern like
+    # 'simplecas/<something>/<something>' (with literal '/' chars) then we will
+    # collide and that record path will be unreachable. I consider this risk to
+    # be low enough to live with for now, and its not worth doing further validation
+    # since this test happens on every request (hence we want to keep it lightweight)
+    if (scalar(@subargs) > 2) {
+      # The pk value form (<path>/<pk_value>/...):
+      $s->(@subargs);
+
+      # The name/value form (<path>/<col_name>/<col_value>/...):
+      if(scalar(@subargs) > 3) {
+        shift @subargs;
+        $s->(@subargs);
+      }
+    }
+  }
+};
 
 
 # --- Handle RESTful URLs - convert 'id/1234' into '?___record_pk=1234'
@@ -411,7 +459,7 @@ sub _resolve_rel_obj_method {
   my ($key,$val,$rel) = split('/',$rs_method,3);
   my $Row = $self->restGetRow($key,$val);
   die usererr "No such relationship $rel at ''$rs_method''" unless ($Row->has_relationship($rel));
-  return $Row->$rel;
+  return wantarray ? (scalar $Row->$rel, $Row) : $Row->$rel;
 }
 
 sub redirect_handle_rest_rel_request {
@@ -419,7 +467,7 @@ sub redirect_handle_rest_rel_request {
   my $c = $self->c;
   
   my $mth_path = join('/',$key,$val,$rel);
-  my $RelObj = $self->_resolve_rel_obj_method($mth_path);
+  my ($RelObj, $Row) = $self->_resolve_rel_obj_method($mth_path);
   my $Src = $RelObj->result_source;
   my $class = $Src->schema->class($Src->source_name);
   
@@ -431,13 +479,35 @@ sub redirect_handle_rest_rel_request {
     my $url = try{$class->TableSpec_get_conf('open_url_multi')}
       or die usererr "No path (open_url_multi) defined to render Result Class: $class";
 
-    %{$c->req->params} = (
-      base_params => $self->json->encode({ 
-        rs_path   => $self->module_path,
-        rs_method => join('/',$key,$val,$rel)
-      })
-    );
-  
+    my $p = {
+      rs_path   => $self->module_path,
+      rs_method => join('/',$key,$val,$rel)
+    };
+
+    # ---
+    # New: For the case of a multi-relationship, attempt to resolve the reverse 
+    # relationship (i.e. the belongs_to) and set the new 'rs_lock_keys' info to
+    # declare to the target Module the fk value that must be maintained and
+    # enforced for this relationship. This is then used when adding new records
+    # and editability of the linking relationship is disabled.
+    if(my $rev_rel_info = $Row->result_source->reverse_relationship_info($rel)) {
+      my ($rev_rel, $info) = %$rev_rel_info;
+      if($info && $info->{cond}) {
+        require RapidApp::DBIC::Component::TableSpec;
+        my $cdta = RapidApp::DBIC::Component::TableSpec
+          ->parse_relationship_cond($info->{cond}) || {};
+        my @pks = $Row->result_source->primary_columns;
+        if(scalar(@pks) == 1 && $cdta->{self} && $cdta->{foreign} && $pks[0] eq $cdta->{foreign}) {
+          $p->{rs_lock_keys} = $self->json->encode({
+            $cdta->{self} => $val,
+            $rev_rel      => $val,
+          });
+        }
+      }
+    }
+    # ---
+
+    %{$c->req->params} = ( %$p, base_params => $self->json->encode( $p ) );
     $c->root_module_controller->approot($c,$url);
     return $c->detach;
   }
@@ -472,6 +542,39 @@ sub redirect_handle_rest_rel_request {
 }
 
 
+sub _get_rs_lock_keys {
+  my $self = shift;
+
+  my $c = RapidApp->active_request_context or return undef;
+  my $lk_enc = $c->req->params->{rs_lock_keys} or return undef;
+  try{$self->json->decode($lk_enc)}
+}
+
+
+before 'store_init_onrequest' => sub {
+  my $self = shift;
+
+  if(my $lock_keys = $self->_get_rs_lock_keys) {
+    my @cols = ();
+    for my $name (keys %$lock_keys) {
+      my $Column = $self->get_column($name) or next;
+      push @cols, $name;
+      # Set the default value of the editor to the locked key value, and then
+      # set to 'disabled' to prevent the user from changing it
+      my $editor = $Column->{editor} or next;
+      $editor->{value} = $lock_keys->{$name};
+      $editor->{disabled} = \1;
+    }
+    if(scalar(@cols) > 0) {
+      # Sets each locked fk to be the first column (top of teh add form), and not editable
+      $self->apply_columns_ordered(0, map { $_ => {
+        allow_edit => \0
+      }} @cols );
+    }
+  }
+};
+
+
 # ---
 
 sub BUILD {}
@@ -726,6 +829,24 @@ sub rs_all {
   $want ? @ret : $ret[0]
 }
 
+
+has '_count_col', is => 'ro', lazy => 1, default => sub {
+  my $self = shift;
+  
+  # We only want to use this optimization for PostgreSQL, since it is
+  # known to perform poorly with the standard count(*) method, which
+  # is uniquely a Pg issue....
+  my $sqlt_type = $self->ResultSource->schema->storage->sqlt_type || '';
+  $sqlt_type eq 'PostgreSQL' or return undef;
+
+  my @pris = $self->ResultSource->primary_columns;
+  if(scalar(@pris) == 1) {
+    return $pris[0];
+  }
+  return undef;
+
+}, isa => 'Maybe[Str]';
+
 sub rs_count { 
   my $self = shift;
   my $Rs2 = shift;
@@ -743,6 +864,26 @@ sub rs_count {
   
   #return $self->rs_count_via_pager($Rs2);
   #return $self->rs_count_manual($Rs2);
+  
+  if(my $col = $self->_count_col) {
+    return try {
+      $Rs2->search_rs(undef,{ 
+        page => undef, rows => undef, order_by => undef,
+        select => { count => join('.',$Rs2->current_source_alias,$col) },
+        as => 'count'
+      })
+      ->get_column('count')
+      ->first
+    }
+    catch {
+      warn RED . "\n\n" . $self->extract_db_error_from_exception($_) . CLEAR;
+      warn RED.BOLD . "\n\n" .
+        'COUNT VIA _count_col FAILED, FAILING BACK TO PAGER COUNT' .
+      "\n\n" . CLEAR;
+      return $self->rs_count_with_fallbacks($Rs2);
+    };
+  }
+  
   return $self->rs_count_with_fallbacks($Rs2);
 }
 
@@ -895,40 +1036,13 @@ sub calculate_column_summaries {
   }
   
   try {
-  
-    my $agg_row;
-    if($Rs->{attrs}->{having}) {
-      # ---
-      # Special support for queries with HAVING clause:
-      #  This is heavily tied in with the custom building of
-      #  'having' in this class and is slated to be refactored at
-      #  some point... Conditions are converted from 'where' to
-      #  'having' for virtual columns. For this case, we need to
-      #  wrap in a subselect because the having relies on the AS
-      #  within the select, which is replaced for the summary query.
-      #  This special handling finally fixes Summary Functions when
-      #  there is a virtual column setup in MultiFilters
-      $agg_row = $self->_chain_search_rs($Rs,undef,{
-        page => undef,
-        rows => undef,
-        order_by => undef,
-      })->as_subselect_rs->search_rs(undef,{
-        select => $select,
-        as => $as,
-      })->first or return;
-      # ---
-    }
-    else {
-      $agg_row = $self->_chain_search_rs($Rs,undef,{
-        page => undef,
-        rows => undef,
-        order_by => undef,
-        select => $select,
-        as => $as
-      })->first or return;
-    }
-    
-    $ret->{column_summaries} = { $agg_row->get_columns, %extra };
+    my $agg = $self->_chain_search_rs($Rs,undef,{
+      rows => 1, page => undef, order_by => undef,
+      select => $select, as => $as,
+      result_class => 'DBIx::Class::ResultClass::HashRefInflator'
+    })->first or return;
+
+    $ret->{column_summaries} = { %$agg, %extra };
   }
   catch {
     $self->c->log->error("$_");
@@ -941,12 +1055,31 @@ sub get_col_summary_select {
   my $col = shift;
   my $func = shift;
   
+  # ---
+  # NEW: Look for and extract the SQL literal from the special ''/-as structure
+  # which is how virtual columns appear. This is the structure needed for the
+  # select, we need to strip this wrapper out for use here
+  $col = $col->{''} if (
+       ref($col) && ref($col) eq 'HASH'
+    && scalar(keys %$col) == 2
+    && $col->{''} && $col->{'-as'}
+  );
+  # Normalize to a ScalarRef from several known nested structures (multi-rel vs virtual)
+  if(ref($col)) {
+    $col = $$col     if (ref($col) eq 'REF');
+    $col = $col->[0] if (ref($col) eq 'ARRAY');
+    $col = \"$col" unless (ref $col);
+  }
+  # ---
+
   $func =~ s/^\s+//;
   $func =~ s/\s+$//;
   
   # Simple function name
   return { uc($func) => $col } if ($func =~ /^[a-zA-Z]+$/);
   
+  $col = $$col if (ref($col) && ref($col) eq 'SCALAR');
+
   # Replace macro string '{x}' with the column name
   $func =~ s/\{x\}/${col}/g;
   
@@ -2186,9 +2319,16 @@ sub process_update_queue {
   my $self = shift;
   my @update_queue = @_;
   
+  my $lock_keys = $self->_get_rs_lock_keys;
+  my @excl = $lock_keys ? keys %$lock_keys : ();
+
   foreach my $upd (@update_queue) {
-    if($upd->{change}) {
-      $upd->{row}->update($upd->{change});
+    if(my $chg = $upd->{change}) {
+      # We simply exclude the lock_keys from the update instead of changing them, because
+      # this is safer. They should already be the same, but if they aren't, it is more
+      # likely taht the client has outdated data than the server is somehow wrong
+      exists $chg->{$_} and delete $chg->{$_} for (@excl);
+      $upd->{row}->update($chg);
     }
     elsif($upd->{rel_update}) {
       # Special handling for updates to relationship columns 
@@ -2682,4 +2822,4 @@ sub batch_update {
 }
 
 
-1;
\ No newline at end of file
+1;
